@@ -5,26 +5,31 @@ parts of this code taken from http://www.djangosnippets.org/snippets/934/
  - thanks baumer1122
 
 """
-import os
 import posixpath
 
 from django import forms
 from django.conf import settings
-from django.utils.functional import curry
 from django.utils.safestring import mark_safe
-from django.core.files.uploadedfile import SimpleUploadedFile as UploadedFile
 
-from form_utils.settings import JQUERY_URL, FORM_UTILS_MEDIA_URL
+from form_utils.settings import JQUERY_URL
 
 try:
-    from sorl.thumbnail.main import DjangoThumbnail
+    from sorl.thumbnail import get_thumbnail
     def thumbnail(image_path, width, height):
-        t = DjangoThumbnail(relative_source=image_path, requested_size=(width,height))
-        return u'<img src="%s" alt="%s" />' % (t.absolute_url, image_path)
+        geometry_string = 'x'.join([str(width), str(height)])
+        t = get_thumbnail(image_path, geometry_string)
+        return u'<img src="%s" alt="%s" />' % (t.url, image_path)
 except ImportError:
-    def thumbnail(image_path, width, height):
-        absolute_url = posixpath.join(settings.MEDIA_URL, image_path)
-        return u'<img src="%s" alt="%s" />' % (absolute_url, image_path)
+    try:
+        from easy_thumbnails.files import get_thumbnailer
+        def thumbnail(image_path, width, height):
+            thumbnail_options = dict(size=(width, height), crop=True)
+            thumbnail = get_thumbnailer(image_path).get_thumbnail(thumbnail_options)
+            return u'<img src="%s" alt="%s" />' % (thumbnail.url, image_path)
+    except ImportError:
+        def thumbnail(image_path, width, height):
+            absolute_url = posixpath.join(settings.MEDIA_URL, image_path)
+            return u'<img src="%s" alt="%s" />' % (absolute_url, image_path)
 
 class ImageWidget(forms.FileInput):
     template = '%(input)s<br />%(image)s'
@@ -76,7 +81,7 @@ class ClearableFileInput(forms.MultiWidget):
                                     'checkbox': rendered_widgets[1]}
         return rendered_widgets[0]
 
-root = lambda path: posixpath.join(FORM_UTILS_MEDIA_URL, path)
+root = lambda path: posixpath.join(settings.STATIC_URL, path)
 
 class AutoResizeTextarea(forms.Textarea):
     """
